package unikl.disco.demos;

import java.awt.Color;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;

import javax.swing.JFrame;

import unikl.disco.nc.Curve;
import unikl.disco.math.functions.FunctionView;

/**
 * Little demo of the class <code>FunctionView</code>.
 * 
 * @author Frank A. Zdarsky
 */
public class FunctionViewDemo extends JFrame {
	private static final long serialVersionUID = 1L;

	// strings containing greek letters (for convenience)
	public static final String ALPHA = "\u03B1";
	public static final String BETA  = "\u03B2";
	public static final String GAMMA = "\u03B3";
	
	private static FunctionViewDemo frame;

	private static int width = 880;

	private static int height = 660;

	private FunctionView f_view;

	public FunctionViewDemo() {
		super("Little Demo of FunctionView");
		Curve.setCreateLabels(true);
	}

	private void createCurves() {
		Curve.setCreateLabels(true);
		
		Curve alpha = Curve.createTokenBucket(100.0, 0.2);
		alpha.setAlias(ALPHA);

		Curve gamma = Curve.createRateLatency(20.0, 1.0);
		gamma.setAlias(GAMMA);

		Curve beta = Curve.createRateLatency(200, 0.6);
		beta.setAlias(BETA);

		Curve output_bound = alpha.convolveAlmostConcave(gamma).deconvolve(beta);
		
		f_view.addFunction(alpha, Color.green);
		f_view.addFunction(beta, Color.blue);
		f_view.addFunction(gamma, Color.red);		
		f_view.addFunction(output_bound, Color.orange);
		
	}

	private void createContentPane() {
		getContentPane().setLayout(new GridBagLayout());

		GridBagConstraints c = new GridBagConstraints();

		f_view = new FunctionView();
		f_view.setAxisLabels("[s]", "[b]");
		f_view.setAxisScales(1.0, 1.0);
		
		c.fill = GridBagConstraints.BOTH;
		c.gridx = 0;
		c.gridy = 0;
		c.weightx = 1.0;
		c.weighty = 1.0;
		getContentPane().add(f_view, c);
	}

	private static void createAndShowGUI() {
		frame = new FunctionViewDemo();
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.createContentPane();
		frame.createCurves();
		frame.setSize(width, height);
		frame.setVisible(true);
	}

	public static void main(String[] args) {
		javax.swing.SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				createAndShowGUI();
			}
		});
	}
}
