/* LoggerStream: provides a central logging facility
 *
 * taken from:
 *  http://blogs.sun.com/nickstephen/entry/java_redirecting_system_out_and
 *
 * @author: Nicos Gollan <gollan@informatik.uni-kl.de>
 */

package unikl.disco.misc;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 *
 * @author ngollan
 */
public class LoggerStream extends ByteArrayOutputStream {
	private String lineSeparator;
	private Logger logger;
	private Level level;

	public LoggerStream(Logger lg, Level lv) {
		super();
		logger = lg;
		level = lv;
		lineSeparator = System.getProperty("line.separator");
	}

	@Override
	public void flush() throws IOException {
		String record;

		synchronized(this) {
			super.flush();
			record = this.toString();
			super.reset();

			if(record.length() > 0 && !record.equals(lineSeparator)) {
				logger.logp(level, "", "", record);
			}
		}
	}
}
