/*
 *  (c) 2005,2006 Frank A. Zdarsky, disco | Distributed Computer Systems Lab
 *                                  University of Kaiserslautern, Germany
 *         All Rights Reserved.
 *
 *  This software is work in progress and is released in the hope that it will
 *  be useful to the scientific community. It is provided "as is" without
 *  express or implied warranty, including but not limited to the correctness
 *  of the code or its suitability for any particular purpose.
 *
 *  You are free to use this software for any non-commercial educational or
 *  research purpose, provided that this copyright notice is not removed or
 *  modified. For commercial uses please contact the respective author(s).
 *
 *  If you find our software useful, we would appreciate if you mentioned it
 *  in any publication arising from the use of this software or acknowledge
 *  our work otherwise. We would also like to hear of any fixes or useful
 *  extensions to this software.
 *
 */

package unikl.disco.nc;

import java.util.List;

import edu.uci.ics.jung.graph.Vertex;
import edu.uci.ics.jung.graph.DirectedEdge;

/**
 * Class representing flows through the network.
 *
 * @author Frank A. Zdarsky
 */
public class Flow {
	private static int next_id = 0;

	/** The flow's ID. */
	public Integer	id;
	/** The flow's arrival curve */
	public Curve    ac;
	/** The vertex at which the flow originates */
	public Vertex	source;
	/** The vertex at which the flow ends */
	public Vertex	sink;
	/** The (edge) path the flow traverses */
	public List<DirectedEdge> path;

	/**
	 * Creates a dummy flow.
	 * @return a dummy flow
	 */
	public static Flow createDummyFlow() {
		return new Flow(null, null, null, null);
	}

	/**
	 * @param source the vertex at which the flow originates
	 * @param sink the vertex at which the flow ends
	 * @param ac the flow's arrival curve
	 * @param path the (edge) path the flow traverses
	 */
	public Flow(Vertex source, Vertex sink, Curve ac, List<DirectedEdge> path) {
		this.id     = new Integer(next_id++);
		this.ac     = ac;
		this.source = source;
		this.sink   = sink;
		this.path   = path;
	}

	/**
	 * Returns a string representation of the flow.
	 * @return a string representation of the flow
	 */
	@Override
	public String toString() {
		return "(" + String.valueOf(id) + "," + String.valueOf(source)
		        + "," + String.valueOf(sink) + "," + String.valueOf(ac)
		        + "," + String.valueOf(path) + ")";
	}
}